import components from './components';
import { VueConstructor } from 'vue';
import VueCompositionAPI from '@vue/composition-api';
import { PluginObject } from 'vue/types/umd';


interface VueConstructorWithCompositionAPI extends VueConstructor {
  __composition_api_installed__?: boolean
}

/**
 * Install all components
 *
 * @param  {Vue}  Vue The Vue object
 * @return {void}
 */
export function install(Vue:VueConstructorWithCompositionAPI) {
  if(!Vue.__composition_api_installed__)
    Vue.use(VueCompositionAPI);

  Object.keys(components).forEach((name) => {
    Vue.component(name, (components as any)[name]);
  });
}

// export class MapboxTs extends Function {
//   testStuff: string;
//   _bound: any;

//   constructor() {
//     super();    
//     return new Proxy(this, {
//       apply: (target, thisArg, args) => target._call()
//     });
//   }

//   _call(Vue:VueConstructor):void {
  
//     Vue.use(VueCompositionAPI);
  
//     Object.keys(components).forEach((name) => {
//       Vue.component(name, (components as any)[name]);
//     });
//   }
// }

// Export each components separately
export * from './components';

// Export the install function as default
export default install;
